@@ -64,6 +64,7 @@ from .type_defs import (
     MetricDatumTypeDef,
     MetricMathAnomalyDetectorTypeDef,
     MetricStreamFilterTypeDef,
+    MetricStreamStatisticsConfigurationTypeDef,
     PutDashboardOutputTypeDef,
     PutMetricStreamOutputTypeDef,
     SingleMetricAnomalyDetectorTypeDef,
@@ -350,8 +351,7 @@ class CloudWatchClient(BaseClient):
         LabelOptions: "LabelOptionsTypeDef" = ...
     ) -> GetMetricDataOutputTypeDef:
         """
-        You can use the `GetMetricData` API to retrieve as many as 500 different metrics
-        in a single request, with a total of as many as 100,800 data points.
+        You can use the `GetMetricData` API to retrieve CloudWatch metric values.
 
         [Show boto3 documentation](https://boto3.amazonaws.com/v1/documentation/api/latest/reference/services/cloudwatch.html#CloudWatch.Client.get_metric_data)
         [Show boto3-stubs documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/client/#get_metric_data)
@@ -554,7 +554,8 @@ class CloudWatchClient(BaseClient):
         OutputFormat: MetricStreamOutputFormatType,
         IncludeFilters: Sequence["MetricStreamFilterTypeDef"] = ...,
         ExcludeFilters: Sequence["MetricStreamFilterTypeDef"] = ...,
-        Tags: Sequence["TagTypeDef"] = ...
+        Tags: Sequence["TagTypeDef"] = ...,
+        StatisticsConfigurations: Sequence["MetricStreamStatisticsConfigurationTypeDef"] = ...
     ) -> PutMetricStreamOutputTypeDef:
         """
         Creates or updates a metric stream.
