@@ -1,7 +1,7 @@
 """
 Type annotations for cloudwatch service literal definitions.
 
-[Open documentation](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/literals.html)
+[Open documentation](https://youtype.github.io/boto3_stubs_docs/mypy_boto3_cloudwatch/literals/)
 
 Usage::
 
@@ -39,9 +39,12 @@ __all__ = (
     "StateValueType",
     "StatisticType",
     "StatusCodeType",
+    "CloudWatchServiceName",
     "ServiceName",
+    "ResourceServiceName",
     "PaginatorName",
     "WaiterName",
+    "RegionName",
 )
 
 
@@ -100,6 +103,7 @@ StandardUnitType = Literal[
 StateValueType = Literal["ALARM", "INSUFFICIENT_DATA", "OK"]
 StatisticType = Literal["Average", "Maximum", "Minimum", "SampleCount", "Sum"]
 StatusCodeType = Literal["Complete", "InternalError", "PartialData"]
+CloudWatchServiceName = Literal["cloudwatch"]
 ServiceName = Literal[
     "accessanalyzer",
     "account",
@@ -131,6 +135,7 @@ ServiceName = Literal[
     "backup",
     "backup-gateway",
     "batch",
+    "billingconductor",
     "braket",
     "budgets",
     "ce",
@@ -217,6 +222,7 @@ ServiceName = Literal[
     "frauddetector",
     "fsx",
     "gamelift",
+    "gamesparks",
     "glacier",
     "globalaccelerator",
     "glue",
@@ -253,6 +259,7 @@ ServiceName = Literal[
     "kafka",
     "kafkaconnect",
     "kendra",
+    "keyspaces",
     "kinesis",
     "kinesis-video-archived-media",
     "kinesis-video-media",
@@ -317,6 +324,7 @@ ServiceName = Literal[
     "pinpoint",
     "pinpoint-email",
     "pinpoint-sms-voice",
+    "pinpoint-sms-voice-v2",
     "polly",
     "pricing",
     "proton",
@@ -401,6 +409,18 @@ ServiceName = Literal[
     "workspaces-web",
     "xray",
 ]
+ResourceServiceName = Literal[
+    "cloudformation",
+    "cloudwatch",
+    "dynamodb",
+    "ec2",
+    "glacier",
+    "iam",
+    "opsworks",
+    "s3",
+    "sns",
+    "sqs",
+]
 PaginatorName = Literal[
     "describe_alarm_history",
     "describe_alarms",
@@ -409,3 +429,27 @@ PaginatorName = Literal[
     "list_metrics",
 ]
 WaiterName = Literal["alarm_exists", "composite_alarm_exists"]
+RegionName = Literal[
+    "af-south-1",
+    "ap-east-1",
+    "ap-northeast-1",
+    "ap-northeast-2",
+    "ap-northeast-3",
+    "ap-south-1",
+    "ap-southeast-1",
+    "ap-southeast-2",
+    "ap-southeast-3",
+    "ca-central-1",
+    "eu-central-1",
+    "eu-north-1",
+    "eu-south-1",
+    "eu-west-1",
+    "eu-west-2",
+    "eu-west-3",
+    "me-south-1",
+    "sa-east-1",
+    "us-east-1",
+    "us-east-2",
+    "us-west-1",
+    "us-west-2",
+]
