@@ -15,8 +15,6 @@ import sys
 from datetime import datetime
 from typing import Dict, List, Sequence, Union
 
-from typing_extensions import NotRequired
-
 from .literals import (
     AlarmTypeType,
     AnomalyDetectorStateValueType,
@@ -116,6 +114,8 @@ __all__ = (
     "MetricStatTypeDef",
     "MetricStreamEntryTypeDef",
     "MetricStreamFilterTypeDef",
+    "MetricStreamStatisticsConfigurationTypeDef",
+    "MetricStreamStatisticsMetricTypeDef",
     "MetricTypeDef",
     "PaginatorConfigTypeDef",
     "PartialFailureTypeDef",
@@ -762,6 +762,7 @@ GetMetricStreamOutputTypeDef = TypedDict(
         "CreationDate": datetime,
         "LastUpdateDate": datetime,
         "OutputFormat": MetricStreamOutputFormatType,
+        "StatisticsConfigurations": List["MetricStreamStatisticsConfigurationTypeDef"],
         "ResponseMetadata": "ResponseMetadataTypeDef",
     },
 )
@@ -1108,6 +1109,22 @@ MetricStreamFilterTypeDef = TypedDict(
     total=False,
 )
 
+MetricStreamStatisticsConfigurationTypeDef = TypedDict(
+    "MetricStreamStatisticsConfigurationTypeDef",
+    {
+        "IncludeMetrics": List["MetricStreamStatisticsMetricTypeDef"],
+        "AdditionalStatistics": List[str],
+    },
+)
+
+MetricStreamStatisticsMetricTypeDef = TypedDict(
+    "MetricStreamStatisticsMetricTypeDef",
+    {
+        "Namespace": str,
+        "MetricName": str,
+    },
+)
+
 MetricTypeDef = TypedDict(
     "MetricTypeDef",
     {
@@ -1323,6 +1340,7 @@ _OptionalPutMetricStreamInputRequestTypeDef = TypedDict(
         "IncludeFilters": Sequence["MetricStreamFilterTypeDef"],
         "ExcludeFilters": Sequence["MetricStreamFilterTypeDef"],
         "Tags": Sequence["TagTypeDef"],
+        "StatisticsConfigurations": Sequence["MetricStreamStatisticsConfigurationTypeDef"],
     },
     total=False,
 )
